# dask-rasterio

`dask-rasterio` provides some methods for reading and writing rasters in
parallel using [Rasterio](https://github.com/mapbox/rasterio) and
[Dask](https://dask.pydata.org) arrays.

## Usage

...

## Install

Install with pip:

```
pip install dask-rasterio
```

## Development

This project is managed by [Poetry](https://github.com/sdispater/poetry).  If
you do not have it installed, please refer to 
[Poetry instructions](https://github.com/sdispater/poetry#installation).

Now, clone the repository and run `poetry install`.  This will create a virtual
environment and install all required packages there.

Run `poetry run pytest` to run all tests.

Run `poetry build` to build package on `dist/`.


## Issue tracker

Please report any bugs and enhancement ideas using the GitHub issue tracker:

  https://github.com/dymaxionlabs/dask-rasterio/issues

Feel free to also ask questions on our
[Gitter channel](https://gitter.im/dymaxionlabs/dask-rasterio), or by email.


## Help wanted

Any help in testing, development, documentation and other tasks is highly
appreciated and useful to the project.

For more details, see the file [CONTRIBUTING.md](CONTRIBUTING.md).


## License

Source code is released under a BSD-2 license.  Please refer to
[LICENSE.md](LICENSE.md) for more information.
